# findCPcore

[![Documentation Status](https://readthedocs.org/projects/findcpcore/badge/?version=latest&style=flat-square)](https://findcpcore.readthedocs.io/en/latest/?badge=latest)		
[![standard-readme compliant](https://img.shields.io/badge/readme%20style-standard-brightgreen.svg?style=flat-square)](https://github.com/RichardLitt/standard-readme)

The documentation can be found at [readthedocs](https://findcpcore.readthedocs.io/en/latest/) and can also be [downloaded](https://findcpcore.readthedocs.io/_/downloads/en/latest/pdf/).

# Source
## Table of Contents
- [Install](#install)
- [Maintainers](#maintainers)
- [Contributing](#contributing)
- [License](#license)

## Install

```sh
$ pip install findCPcore
```


## Maintainers

[@alexOarga](https://github.com/alexOarga)

## Contributing

Feel free to dive in! [Open an issue](https://github.com/findCP/findCPcore/issues) or submit PRs.

Standard Readme follows the [Contributor Covenant](http://contributor-covenant.org/version/1/3/0/) Code of Conduct.

## License

[MIT](LICENSE) © Alex Oarga
